##########
 Telegram
##########

.. automodule:: bohicalog.handlers.telegram
   :members:

.. automodule:: bohicalog.handlers.telegram.handler
   :members:

.. automodule:: bohicalog.handlers.telegram.buffer
   :members:

.. automodule:: bohicalog.handlers.telegram.consts
   :members:

.. automodule:: bohicalog.handlers.telegram.formatters
   :members:

.. automodule:: bohicalog.handlers.telegram.utils
   :members:
